pub struct ExecTester { /* private fields */ }Expand description
An execution tester strategy for live testing order execution functionality.
This strategy is designed for testing execution adapters by submitting limit orders, stop orders, and managing positions. It can maintain orders at a configurable offset from the top of book.
WARNING: This strategy has no alpha advantage whatsoever. It is not intended to be used for live trading with real money.
Implementations
Sourceimpl ExecTester
impl ExecTester
Sourceimpl ExecTester
impl ExecTester
Sourcepub fn new(config: ExecTesterConfig) -> Self
pub fn new(config: ExecTesterConfig) -> Self
Creates a new ExecTester instance.